@@ -13,7 +13,6 @@ rd2ex <- function(x, ...) {
 run_examples <- function(x,
                          topic = "unknown",
                          env = globalenv(),
-                         run_examples = TRUE,
                          run_dont_run = FALSE
                          ) {
 
@@ -34,7 +33,7 @@ run_examples <- function(x,
     return("")
   }
 
-  if (run_examples) {
+  if (!is.null(env)) {
     highlight_examples(code, topic, env = env)
   } else {
     highlight_text(code)
@@ -93,25 +92,7 @@ process_conditional_examples <- function(rd) {
   }
 }
 
-highlight_examples <- function(code, topic, env = globalenv()) {
-  bg <- context_get("figures")$bg %||% NA
-  withr::local_options(list(
-    crayon.enabled = TRUE,
-    crayon.colors = 256,
-    device = function(...) ragg::agg_png(..., bg = bg)
-  ))
 
-  fig_save_topic <- function(plot, id) {
-    name <- paste0(topic, "-", id)
-    do.call(fig_save, c(list(plot, name), context_get("figures")))
-  }
-
-  downlit::evaluate_and_highlight(
-    code,
-    fig_save = fig_save_topic,
-    env = child_env(env)
-  )
-}
 
 # as_example --------------------------------------------------------------
 
@@ -125,7 +106,17 @@ as_example.RCODE <- function(x, run_dont_run = FALSE) as.character(x)
 as_example.VERB <- as_example.RCODE
 #' @export
 as_example.TEXT <- as_example.RCODE
-
+#' @export
+as_example.COMMENT <- function(x, run_dont_run = FALSE) {
+  if (grepl("^%[^ ]*%", x)) {
+    warning(
+      "In the examples,  ", unclass(x), "\n",
+      "is an Rd comment: did you mean  ", gsub("%", "\\\\%", x), " ?",
+      call. = FALSE
+    )
+  }
+  ""
+}
 #' @export
 as_example.tag_dontrun <- function(x, run_dont_run = FALSE) {
   if (run_dont_run) {
