@@ -13,13 +13,15 @@ test_that("render_rmarkdown copies image files in subdirectories", {
 })
 
 test_that("render_rmarkdown yields useful error", {
-  skip_on_cran() # don't understand why it fails on CRAN
+  skip_on_cran() # fragile due to pandoc dependency
+  skip_if_no_pandoc("2.18")
 
   tmp <- dir_create(file_temp())
   pkg <- list(src_path = test_path("."), dst_path = tmp, bs_version = 3)
 
   expect_snapshot(error = TRUE, {
-    render_rmarkdown(pkg, "assets/pandoc-fail.Rmd", "test.html")
+    render_rmarkdown(pkg, "assets/pandoc-fail.Rmd", "test.html",
+        output_format = rmarkdown::html_document(pandoc_args = "--fail-if-warnings"))
   })
 })
 
